@@ -5,13 +5,13 @@ as.Date.timeDate <- timeDate::as.Date.timeDate
 
 
 #' Number of trading days in each season
-#' 
+#'
 #' Returns number of trading days in each month or quarter of the observed time
 #' period in a major financial center.
-#' 
+#'
 #' Useful for trading days length adjustments. More on how to define "business
 #' days", please refer to \code{\link[timeDate]{isBizday}}.
-#' 
+#'
 #' @param x Monthly or quarterly time series
 #' @param FinCenter Major financial center.
 #' @return Time series
@@ -19,13 +19,15 @@ as.Date.timeDate <- timeDate::as.Date.timeDate
 #' @seealso \code{\link[forecast]{monthdays}}
 #' @keywords ts
 #' @examples
-#' 
+#'
 #'   x <-  ts(rnorm(30), start = c(2013, 2), frequency = 12)
 #'   bizdays(x, FinCenter = "New York")
-#' 
+#'
 #' @export
-bizdays <- function(x, FinCenter = c("New York", "London", "NERC", "Tokyo",
-                                     "Zurich")) {
+bizdays <- function(x, FinCenter = c(
+                    "New York", "London", "NERC", "Tokyo",
+                    "Zurich"
+                  )) {
   # Return the number of trading days corresponding to the input ts
   #
   # Args:
@@ -53,7 +55,7 @@ bizdays <- function(x, FinCenter = c("New York", "London", "NERC", "Tokyo",
   } else if (FinCenter == "Zurich") {
     holidays <- timeDate::holidayZURICH(years)
   }
-  if (freq == 12L) {  # monthly data
+  if (freq == 12L) { # monthly data
     date <- zoo::as.Date(time(x))
     start <- date[1L]
     end <- seq(date[length(date)], length = 2L, by = "month")[2L] - 1L
@@ -61,7 +63,7 @@ bizdays <- function(x, FinCenter = c("New York", "London", "NERC", "Tokyo",
     # Grab business days
     biz <- days.len[timeDate::isBizday(days.len, holidays = holidays)]
     bizdays <- format(biz, format = "%Y-%m")
-  } else if (freq == 4L) {  # Quarterly data
+  } else if (freq == 4L) { # Quarterly data
     date <- zoo::as.Date(time(x))
     start <- date[1L]
     end <- seq(date[length(date)], length = 2L, by = "3 month")[2L] - 1L
@@ -69,13 +71,12 @@ bizdays <- function(x, FinCenter = c("New York", "London", "NERC", "Tokyo",
     # Grab business days
     biz <- days.len[timeDate::isBizday(days.len, holidays = holidays)]
     bizdays <- format(zoo::as.yearqtr(biz), format = "%Y Qtr%q")
-    
   } # else if (freq == 52L) {  # Weekly data
   #   start <- paste0(start(x)[1L], "-01-01")
   #   start <- as.Date(start) + start(x)[2L] * 7L
   #   end <- start + length(time(x)) * 7L
   #   days.len <- as.timeDate(seq(start, end, by = "days"), FinCenter = FinCenter)
-  #   biz <- days.len[isBizday(days.len, 
+  #   biz <- days.len[isBizday(days.len,
   #                            holidays = unique(format(days.len, "%Y")))]
   #   bizdays <- format(biz, format = "%Y Wk%W")
   # }
@@ -87,14 +88,14 @@ bizdays <- function(x, FinCenter = c("New York", "London", "NERC", "Tokyo",
 
 
 #' Easter holidays in each season
-#' 
+#'
 #' Returns a vector of 0's and 1's or fractional results if Easter spans March
 #' and April in the observed time period. Easter is defined as the days from
 #' Good Friday to Easter Sunday inclusively, plus optionally Easter Monday if
 #' \code{easter.mon=TRUE}.
-#' 
+#'
 #' Useful for adjusting calendar effects.
-#' 
+#'
 #' @param x Monthly or quarterly time series
 #' @param easter.mon If TRUE, the length of Easter holidays includes Easter
 #' Monday.
@@ -102,9 +103,9 @@ bizdays <- function(x, FinCenter = c("New York", "London", "NERC", "Tokyo",
 #' @author Earo Wang
 #' @keywords ts
 #' @examples
-#' 
+#'
 #'   easter(wineind, easter.mon = TRUE)
-#' 
+#'
 #' @export
 easter <- function(x, easter.mon = FALSE) {
   # Return a vector of 0's and 1's for easter holidays
@@ -129,7 +130,7 @@ easter <- function(x, easter.mon = FALSE) {
   if (freq == 12L) {
     fmat <- "%Y-%m"
     yr.mon <- format(date, format = fmat)
-    gd.fri <- format(gd.fri0, format = fmat)  # good fri
+    gd.fri <- format(gd.fri0, format = fmat) # good fri
     easter <- format(easter0, format = fmat) # easter mon
   } else if (freq == 4L) {
     fmat <- "%Y-%q"
@@ -137,7 +138,7 @@ easter <- function(x, easter.mon = FALSE) {
     gd.fri <- format(zoo::as.yearqtr(gd.fri0), format = fmat)
     easter <- format(zoo::as.yearqtr(easter0), format = fmat)
   }
-  span <- cbind(gd.fri, easter)  # the span of easter holidays
+  span <- cbind(gd.fri, easter) # the span of easter holidays
   hdays <- unlist(apply(span, 1, unique))
   dummies <- ifelse(yr.mon %in% hdays, 1L, 0L)
   # Allow fractional results
@@ -152,7 +153,7 @@ easter <- function(x, easter.mon = FALSE) {
     dif <- dif[-length(dif)]
   }
   replace <- dif > denominator | dif <= 0L
-  dif[replace] <- denominator  # Easter in the same month
+  dif[replace] <- denominator # Easter in the same month
   # Start to insert the remaining part falling in Apr
   index <- which(dif != denominator)
   if (length(index) != 0L) {
@@ -162,7 +163,7 @@ easter <- function(x, easter.mon = FALSE) {
       dif <- append(dif, values = values[i], new.index)
       new.index <- index[i + 1L] + i
     }
-    dummies[dummies == 1L] <- round(dif/unclass(denominator), digits = 2)
+    dummies[dummies == 1L] <- round(dif / unclass(denominator), digits = 2)
   }
   out <- ts(dummies, start = tsp(x)[1L], frequency = freq)
   return(out)
