@@ -5,41 +5,38 @@
 ## test enables a subset of x and f to be tested.
 # MASE: d is the # of differencing
 # MASE: D is the # of seasonal differencing
-testaccuracy <- function(f,x,test,d,D)
-{
+testaccuracy <- function(f, x, test, d, D) {
   dx <- getResponse(f)
-  if(is.data.frame(x))
-  {
+  if (is.data.frame(x)) {
     responsevar <- as.character(formula(f$model))[2]
-    if(is.element(responsevar, colnames(x)))
-      x <- x[,responsevar]
-    else
+    if (is.element(responsevar, colnames(x))) {
+      x <- x[, responsevar]
+    } else {
       stop("I can't figure out what data to use.")
+    }
   }
-  if(is.list(f))
-  {
-    if(is.element("mean",names(f)))
+  if (is.list(f)) {
+    if (is.element("mean", names(f))) {
       f <- f$mean
-    else
+    } else {
       stop("Unknown list structure")
+    }
   }
-  if(is.ts(x) & is.ts(f))
-  {
+  if (is.ts(x) && is.ts(f)) {
     tspf <- tsp(f)
     tspx <- tsp(x)
-    start <- max(tspf[1],tspx[1])
-    end <- min(tspf[2],tspx[2])
+    start <- max(tspf[1], tspx[1])
+    end <- min(tspf[2], tspx[2])
     # Adjustment to allow for floating point issues
-    start <- min(start,end)
-    end <- max(start,end)
-    f <- window(f,start=start,end=end)
-    x <- window(x,start=start,end=end)
+    start <- min(start, end)
+    end <- max(start, end)
+    f <- window(f, start = start, end = end)
+    x <- window(x, start = start, end = end)
   }
   n <- length(x)
-  if(is.null(test))
+  if (is.null(test)) {
     test <- 1:n
-  else if(min(test) < 1 | max(test) > n)
-  {
+  } else if (min(test) < 1 || max(test) > n) {
     warning("test elements must be within sample")
     test <- test[test >= 1 & test <= n]
   }
@@ -48,23 +45,23 @@ testaccuracy <- function(f,x,test,d,D)
   xx <- x
 
   # Check length of f
-  if(length(f) < n)
+  if (length(f) < n) {
     stop("Not enough forecasts. Check that forecasts and test data match.")
+  }
 
-  error <- (xx-ff[1:n])[test]
-  pe <- error/xx[test] * 100
+  error <- (xx - ff[1:n])[test]
+  pe <- error / xx[test] * 100
 
-  me <- mean(error, na.rm=TRUE)
-  mse <- mean(error^2, na.rm=TRUE)
-  mae <- mean(abs(error), na.rm=TRUE)
-  mape <- mean(abs(pe), na.rm=TRUE)
-  mpe <-  mean(pe, na.rm=TRUE)
-  out <- c(me,sqrt(mse),mae,mpe,mape)
-  names(out) <- c("ME","RMSE","MAE","MPE","MAPE")
+  me <- mean(error, na.rm = TRUE)
+  mse <- mean(error ^ 2, na.rm = TRUE)
+  mae <- mean(abs(error), na.rm = TRUE)
+  mape <- mean(abs(pe), na.rm = TRUE)
+  mpe <- mean(pe, na.rm = TRUE)
+  out <- c(me, sqrt(mse), mae, mpe, mape)
+  names(out) <- c("ME", "RMSE", "MAE", "MPE", "MAPE")
 
   # Compute MASE if historical data available
-  if(!is.null(dx))
-  {
+  if (!is.null(dx)) {
     tspdx <- tsp(dx)
     if (!is.null(tspdx)) {
       if (D > 0) { # seasonal differencing
@@ -79,49 +76,49 @@ testaccuracy <- function(f,x,test,d,D)
       }
       scale <- mean(abs(nd), na.rm = TRUE)
     } else { # not time series
-      scale <- mean(abs(dx-mean(dx, na.rm=TRUE)),na.rm=TRUE)
+      scale <- mean(abs(dx - mean(dx, na.rm = TRUE)), na.rm = TRUE)
     }
-    mase <- mean(abs(error/scale), na.rm=TRUE)
-    out <- c(out,mase)
+    mase <- mean(abs(error / scale), na.rm = TRUE)
+    out <- c(out, mase)
     names(out)[length(out)] <- "MASE"
   }
 
   # Additional time series measures
-  if(!is.null(tsp(x)) & n>1)
-  {
-    fpe <- (c(ff[2:n])/c(xx[1:(n-1)]) - 1)[test-1]
-    ape <- (c(xx[2:n])/c(xx[1:(n-1)]) - 1)[test-1]
-    theil <- sqrt(sum((fpe - ape)^2, na.rm=TRUE)/sum(ape^2, na.rm=TRUE))
-    if(length(error) > 1)
-      r1 <- acf(error,plot=FALSE,lag.max=2,na.action=na.pass)$acf[2,1,1]
-    else
+  if (!is.null(tsp(x)) && n > 1) {
+    fpe <- (c(ff[2:n]) / c(xx[1:(n - 1)]) - 1)[test - 1]
+    ape <- (c(xx[2:n]) / c(xx[1:(n - 1)]) - 1)[test - 1]
+    theil <- sqrt(sum((fpe - ape) ^ 2, na.rm = TRUE) / sum(ape ^ 2, na.rm = TRUE))
+    if (length(error) > 1) {
+      r1 <- acf(error, plot = FALSE, lag.max = 2, na.action = na.pass)$acf[2, 1, 1]
+    } else {
       r1 <- NA
+    }
     nj <- length(out)
-    out <- c(out,r1,theil)
-    names(out)[nj+(1:2)] <- c("ACF1","Theil's U")
+    out <- c(out, r1, theil)
+    names(out)[nj + (1:2)] <- c("ACF1", "Theil's U")
   }
 
   return(out)
 }
 
 
-trainingaccuracy <- function(f,test,d, D)
-{
+trainingaccuracy <- function(f, test, d, D) {
   # Make sure x is an element of f when f is a fitted model rather than a forecast
-  #if(!is.list(f))
+  # if(!is.list(f))
   #  stop("f must be a forecast object or a time series model object.")
   dx <- getResponse(f)
-  if(is.element("splineforecast",class(f)))
+  if (is.element("splineforecast", class(f))) {
     fits <- f$onestepf
-  else
-    fits <- fitted(f)    # Don't use f$resid as this may contain multiplicative errors.
+  } else {
+    fits <- fitted(f)
+  } # Don't use f$resid as this may contain multiplicative errors.
 
-  res <- dx-fits
+  res <- dx - fits
   n <- length(res)
-  if(is.null(test))
+  if (is.null(test)) {
     test <- 1:n
-  if(min(test) < 1 | max(test) > n)
-  {
+  }
+  if (min(test) < 1 || max(test) > n) {
     warning("test elements must be within sample")
     test <- test[test >= 1 & test <= n]
   }
@@ -130,19 +127,18 @@ trainingaccuracy <- function(f,test,d, D)
 
   res <- res[test]
   dx <- dx[test]
-  pe <- res/dx * 100 # Percentage error
+  pe <- res / dx * 100 # Percentage error
 
-  me <- mean(res,na.rm=TRUE)
-  mse <- mean(res^2,na.rm=TRUE)
-  mae <- mean(abs(res),na.rm=TRUE)
-  mape <- mean(abs(pe),na.rm=TRUE)
-  mpe <-  mean(pe,na.rm=TRUE)
-  out <- c(me,sqrt(mse),mae,mpe,mape)
-  names(out) <- c("ME","RMSE","MAE","MPE","MAPE")
+  me <- mean(res, na.rm = TRUE)
+  mse <- mean(res ^ 2, na.rm = TRUE)
+  mae <- mean(abs(res), na.rm = TRUE)
+  mape <- mean(abs(pe), na.rm = TRUE)
+  mpe <- mean(pe, na.rm = TRUE)
+  out <- c(me, sqrt(mse), mae, mpe, mape)
+  names(out) <- c("ME", "RMSE", "MAE", "MPE", "MAPE")
 
   # Compute MASE if historical data available
-  if(!is.null(dx))
-  {
+  if (!is.null(dx)) {
     if (!is.null(tspdx)) {
       if (D > 0) { # seasonal differencing
         nsd <- diff(dx, lag = round(tspdx[3L]), differences = D)
@@ -156,23 +152,23 @@ trainingaccuracy <- function(f,test,d, D)
       }
       scale <- mean(abs(nd), na.rm = TRUE)
     } else { # not time series
-      scale <- mean(abs(dx-mean(dx, na.rm=TRUE)),na.rm=TRUE)
+      scale <- mean(abs(dx - mean(dx, na.rm = TRUE)), na.rm = TRUE)
     }
-    mase <- mean(abs(res/scale), na.rm=TRUE)
-    out <- c(out,mase)
+    mase <- mean(abs(res / scale), na.rm = TRUE)
+    out <- c(out, mase)
     names(out)[length(out)] <- "MASE"
   }
 
   # Additional time series measures
-  if(!is.null(tspdx))
-  {
-    if(length(res) > 1)
-      r1 <- acf(res,plot=FALSE,lag.max=2,na.action=na.pass)$acf[2,1,1]
-    else
+  if (!is.null(tspdx)) {
+    if (length(res) > 1) {
+      r1 <- acf(res, plot = FALSE, lag.max = 2, na.action = na.pass)$acf[2, 1, 1]
+    } else {
       r1 <- NA
+    }
     nj <- length(out)
-    out <- c(out,r1)
-    names(out)[nj+1] <- "ACF1"
+    out <- c(out, r1)
+    names(out)[nj + 1] <- "ACF1"
   }
 
   return(out)
@@ -228,9 +224,10 @@ trainingaccuracy <- function(f,test,d, D)
 #' @author Rob J Hyndman
 #' @references Hyndman, R.J. and Koehler, A.B. (2006) "Another look at measures
 #' of forecast accuracy". \emph{International Journal of Forecasting},
-#' \bold{22}(4), 679-688. Hyndman, R.J. and Athanasopoulos, G. (2014)
-#' "Forecasting: principles and practice", OTexts. Section 2.5 "Evaluating
-#' forecast accuracy". \url{http://www.otexts.org/fpp/2/5}.
+#' \bold{22}(4), 679-688. Hyndman, R.J. and Athanasopoulos, G. (2018)
+#' "Forecasting: principles and practice", 2nd ed., OTexts, Melbourne, Australia. 
+#' Section 3.4 "Evaluating forecast accuracy". 
+#' \url{https://otexts.org/fpp2/accuracy.html}.
 #' @keywords ts
 #' @examples
 #'
@@ -243,104 +240,106 @@ trainingaccuracy <- function(f,test,d, D)
 #' plot(fit1)
 #' lines(EuStockMarkets[1:300,1])
 #' @export
-accuracy <- function(f, ...)
-{
+accuracy <- function(f, ...) {
   UseMethod("accuracy")
 }
 
 #' @rdname accuracy
 #' @method accuracy default
 #' @export
-accuracy.default <- function(f, x, test=NULL, d=NULL, D=NULL, ...)
-{
-  if(!any(is.element(class(f), c("mforecast","forecast","ts","integer","numeric",
-      "Arima","ets","lm","bats","tbats","nnetar","stlm"))))
+accuracy.default <- function(f, x, test=NULL, d=NULL, D=NULL, ...) {
+  if (!any(is.element(class(f), c(
+    "mforecast", "forecast", "ts", "integer", "numeric",
+    "Arima", "ets", "lm", "bats", "tbats", "nnetar", "stlm", "baggedModel"
+  )))) {
     stop("First argument should be a forecast object or a time series.")
-  if(is.element("mforecast", class(f)))
-    return(accuracy.mforecast(f,x,test,d,D))
+  }
+  if (is.element("mforecast", class(f))) {
+    return(accuracy.mforecast(f, x, test, d, D))
+  }
 
   trainset <- (is.list(f))
   testset <- (!missing(x))
-  if(testset & !is.null(test))
+  if (testset && !is.null(test)) {
     trainset <- FALSE
-  if(!trainset & !testset)
+  }
+  if (!trainset && !testset) {
     stop("Unable to compute forecast accuracy measures")
+  }
 
   # Find d and D
-  if(is.null(D) & is.null(d))
-  {
-    if(testset)
-    {
+  if (is.null(D) && is.null(d)) {
+    if (testset) {
       d <- as.numeric(frequency(x) == 1)
       D <- as.numeric(frequency(x) > 1)
     }
-    else if(trainset)
-    {
-      if(!is.null(f$mean))
-      {
+    else if (trainset) {
+      if (!is.null(f$mean)) {
         d <- as.numeric(frequency(f$mean) == 1)
         D <- as.numeric(frequency(f$mean) > 1)
       }
-      else
-      {
+      else {
         d <- as.numeric(frequency(f$x) == 1)
         D <- as.numeric(frequency(f$x) > 1)
       }
     }
-    else
-    {
-      d <- as.numeric(frequency(f)==1)
+    else {
+      d <- as.numeric(frequency(f) == 1)
       D <- as.numeric(frequency(f) > 1)
     }
   }
 
 
-  if(trainset)
-  {
-    trainout <- trainingaccuracy(f,test,d,D)
+  if (trainset) {
+    trainout <- trainingaccuracy(f, test, d, D)
     trainnames <- names(trainout)
   }
-  else
+  else {
     trainnames <- NULL
-  if(testset)
-  {
-    testout <- testaccuracy(f,x,test,d,D)
+  }
+  if (testset) {
+    testout <- testaccuracy(f, x, test, d, D)
     testnames <- names(testout)
   }
-  else
+  else {
     testnames <- NULL
-  outnames <- unique(c(trainnames,testnames))
+  }
+  outnames <- unique(c(trainnames, testnames))
 
-  out <- matrix(NA,nrow=2,ncol=length(outnames))
+  out <- matrix(NA, nrow = 2, ncol = length(outnames))
   colnames(out) <- outnames
-  rownames(out) <- c("Training set","Test set")
-  if(trainset)
-    out[1,names(trainout)] <- trainout
-  if(testset)
-    out[2,names(testout)] <- testout
+  rownames(out) <- c("Training set", "Test set")
+  if (trainset) {
+    out[1, names(trainout)] <- trainout
+  }
+  if (testset) {
+    out[2, names(testout)] <- testout
+  }
 
-  if(!testset)
-    out <- out[1,,drop=FALSE]
-  if(!trainset)
-    out <- out[2,,drop=FALSE]
+  if (!testset) {
+    out <- out[1, , drop = FALSE]
+  }
+  if (!trainset) {
+    out <- out[2, , drop = FALSE]
+  }
   return(out)
 }
 
 # Compute accuracy for an mforecast object
 #' @export
-accuracy.mforecast <- function(f, x, test=NULL, d, D, ...)
-{
+accuracy.mforecast <- function(f, x, test=NULL, d, D, ...) {
   object <- f
   out <- NULL
   nox <- missing(x)
   i <- 1
-  for(fcast in object$forecast)
+  for (fcast in object$forecast)
   {
-    if(nox)
-      out1 <- accuracy(fcast, test=test, d=d, D=D)
-    else
-      out1 <- accuracy(fcast, x[,i], test, d, D)
-    rownames(out1) <- paste(fcast$series,rownames(out1))
+    if (nox) {
+      out1 <- accuracy(fcast, test = test, d = d, D = D)
+    } else {
+      out1 <- accuracy(fcast, x[, i], test, d, D)
+    }
+    rownames(out1) <- paste(fcast$series, rownames(out1))
     out <- rbind(out, out1)
     i <- i + 1
   }
